Module algorithms

Module algorithms 

Functions

aitken_sum
Accelerates a linearly converging series using Aitken’s Δ^2 process.
newtons_method
Newton’s method for finding roots of a function.
prod_f
Computes the sum of a function f evaluated over the range [start, end).
reduce_array
Reduces the elements of values using the binary operation op in O(n) steps, but with a dependency depth of O(log n), allowing for better instruction-level parallelism.
reduce_in_place
Reduces the elements of values in place using the binary operation op in O(n) steps, but with a dependency depth of O(log n), allowing for better instruction-level parallelism.
sum_f
Computes the sum of a function f evaluated over the range [start, end).