NegMasked

Trait NegMasked 

pub trait NegMasked<Mask>: Neg {
    // Required methods
    fn neg_c(self, mask: Mask) -> Self::Output;
    fn neg_m(self, src: Self, mask: Mask) -> Self::Output;
    fn neg_z(self, mask: Mask) -> Self::Output;
}
Masked variants of the Neg trait.

Required Methods

fn neg_c(self, mask: Mask) -> Self::Output

Computes Neg where mask is true, does nothing where false.

fn neg_m(self, src: Self, mask: Mask) -> Self::Output

Merges Neg with src using mask, returning src where mask is false.

fn neg_z(self, mask: Mask) -> Self::Output

Computes Neg masked (zeroed where mask is false).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors