NotMasked

Trait NotMasked 

pub trait NotMasked<Mask>: Not {
    // Required methods
    fn not_c(self, mask: Mask) -> Self::Output;
    fn not_m(self, src: Self, mask: Mask) -> Self::Output;
    fn not_z(self, mask: Mask) -> Self::Output;
}
Masked variants of the Not trait.

Required Methods

fn not_c(self, mask: Mask) -> Self::Output

Computes Not where mask is true, does nothing where false.

fn not_m(self, src: Self, mask: Mask) -> Self::Output

Merges Not with src using mask, returning src where mask is false.

fn not_z(self, mask: Mask) -> Self::Output

Computes Not masked (zeroed where mask is false).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors