NumVector

Struct NumVector 

#[repr(transparent)]
pub struct NumVector<V: GenericVector>(pub V);
Wraps a generic vector to provide implementations of num_traits traits.

num_traits is a widely used crate that provides numeric traits for Rust types. However, unless you want to use these, implementing them on all vector types would cause conflicts with more inherent methods provided by this library.

Therefore, this wrapper type allows you to opt-in to using num_traits when needed, without causing conflicts in the main vector types.

Notably, the implementation of MulAdd uses mul_adde under the hood, which may fall back to separate multiply and add operations if a fused multiply-add is not available for the target architecture.

Tuple Fields

0: V