VectorValue

Trait VectorValue 

pub trait VectorValue<C, V: Sized>: Sized {
    const VALUE: V;
}
Associates a constant carrier C with the concrete vector constant V it produces.

The final link in the const-construction chain: a SplatVector::Splat / NewVector::New type implements this to expose the actual const VALUE: V for a given carrier. This indirection is what lets a generic vector type turn a compile-time constant into an instance of itself without const generics over arbitrary types.

Required Associated Constants

const VALUE: V

The materialized vector constant.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> VectorValue<T, <f32 as CoreRegister>::Storage> for f32

Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <f64 as CoreRegister>::Storage> for f64

Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <i8 as CoreRegister>::Storage> for i8
where T: NewConst<<i8 as Register>::Element, <i8 as CoreRegister>::Lanes>,

Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <i16 as CoreRegister>::Storage> for i16

Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <i32 as CoreRegister>::Storage> for i32

Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <i64 as CoreRegister>::Storage> for i64

Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <u8 as CoreRegister>::Storage> for u8
where T: NewConst<<u8 as Register>::Element, <u8 as CoreRegister>::Lanes>,

Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <u16 as CoreRegister>::Storage> for u16

Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <u32 as CoreRegister>::Storage> for u32

Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <u64 as CoreRegister>::Storage> for u64

Source

const VALUE: Storage<Self>

Implementors

Source

impl<T> VectorValue<T, <F32x4V1 as CoreRegister>::Storage> for F32x4V1

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <F32x4V2 as CoreRegister>::Storage> for F32x4V2

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <F32x4V3 as CoreRegister>::Storage> for F32x4V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <F32x8V3 as CoreRegister>::Storage> for F32x8V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <F64x2V1 as CoreRegister>::Storage> for F64x2V1

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <F64x2V2 as CoreRegister>::Storage> for F64x2V2

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <F64x2V3 as CoreRegister>::Storage> for F64x2V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <F64x4V3 as CoreRegister>::Storage> for F64x4V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I8x16V1 as CoreRegister>::Storage> for I8x16V1

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I8x16V2 as CoreRegister>::Storage> for I8x16V2

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I8x16V3 as CoreRegister>::Storage> for I8x16V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I8x32V3 as CoreRegister>::Storage> for I8x32V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I16x8V1 as CoreRegister>::Storage> for I16x8V1

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I16x8V2 as CoreRegister>::Storage> for I16x8V2

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I16x8V3 as CoreRegister>::Storage> for I16x8V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I16x16V3 as CoreRegister>::Storage> for I16x16V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I32x4V1 as CoreRegister>::Storage> for I32x4V1

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I32x4V2 as CoreRegister>::Storage> for I32x4V2

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I32x4V3 as CoreRegister>::Storage> for I32x4V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I32x8V3 as CoreRegister>::Storage> for I32x8V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I64x2V1 as CoreRegister>::Storage> for I64x2V1

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I64x2V2 as CoreRegister>::Storage> for I64x2V2

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I64x2V3 as CoreRegister>::Storage> for I64x2V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <I64x4V3 as CoreRegister>::Storage> for I64x4V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U8x16V1 as CoreRegister>::Storage> for U8x16V1

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U8x16V2 as CoreRegister>::Storage> for U8x16V2

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U8x16V3 as CoreRegister>::Storage> for U8x16V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U8x32V3 as CoreRegister>::Storage> for U8x32V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U16x8V1 as CoreRegister>::Storage> for U16x8V1

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U16x8V2 as CoreRegister>::Storage> for U16x8V2

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U16x8V3 as CoreRegister>::Storage> for U16x8V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U16x16V3 as CoreRegister>::Storage> for U16x16V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U32x4V1 as CoreRegister>::Storage> for U32x4V1

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U32x4V2 as CoreRegister>::Storage> for U32x4V2

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U32x4V3 as CoreRegister>::Storage> for U32x4V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U32x8V3 as CoreRegister>::Storage> for U32x8V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U64x2V1 as CoreRegister>::Storage> for U64x2V1

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U64x2V2 as CoreRegister>::Storage> for U64x2V2

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U64x2V3 as CoreRegister>::Storage> for U64x2V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>

Source

impl<T> VectorValue<T, <U64x4V3 as CoreRegister>::Storage> for U64x4V3

Available on x86 or x86-64 only.
Source

const VALUE: Storage<Self>