pub struct UnalignedMut<'a, V: GenericVector>(/* private fields */);Expand description
A mutable view over a slice of elements that allows unaligned vector loads and stores.
This can be constructed via GenericVector::iter_mut_unaligned.
Implementations
Sourceimpl<'a, V: GenericVector> UnalignedMut<'a, V>
impl<'a, V: GenericVector> UnalignedMut<'a, V>
Sourcepub fn write(&mut self, idx: usize, value: V) -> bool
pub fn write(&mut self, idx: usize, value: V) -> bool
Write a vector at the given index. Returns false if the index is out of bounds.
Sourcepub const fn as_mut_slice<'b>(&'a mut self) -> &'b mut [V::Element]where
'a: 'b,
pub const fn as_mut_slice<'b>(&'a mut self) -> &'b mut [V::Element]where
'a: 'b,
Get the underlying mutable slice.
Sourcepub fn try_aligned_mut(self) -> Result<&'a mut [V], Self>
pub fn try_aligned_mut(self) -> Result<&'a mut [V], Self>
Attempt to get an aligned mutable slice of vectors.
Returns None if the underlying slice is not properly aligned.
This is provided for cases where UnalignedMut was constructed from
a slice that is actually aligned, allowing for more efficient processing.
Methods from Deref<Target = Unaligned<'a, V>>
Sourcepub fn read(&self, idx: usize) -> Option<V>
pub fn read(&self, idx: usize) -> Option<V>
Read a vector at the given index. Returns None if the index is out of bounds.
Sourcepub fn try_aligned(&self) -> Option<&'a [V]>
pub fn try_aligned(&self) -> Option<&'a [V]>
Attempt to get an aligned slice of vectors.
Returns None if the underlying slice is not properly aligned.
This is provided for cases where Unaligned was constructed from
a slice that is actually aligned, allowing for more efficient processing.