#[repr(transparent)]pub struct NumVector<V: GenericVector>(pub V);Expand description
Wraps a generic vector to provide implementations of num_traits traits.
num_traits is a widely used crate that provides numeric traits for Rust types.
However, unless you want to use these, implementing them on all vector types
would cause conflicts with more inherent methods provided by this library.
Therefore, this wrapper type allows you to opt-in to using num_traits
when needed, without causing conflicts in the main vector types.
Notably, the implementation of MulAdd uses mul_adde under the hood,
which may fall back to separate multiply and add operations if a fused multiply-add
is not available for the target architecture.
Tuple Fields
0: VTrait Implementations
Sourceimpl<V: NumericVector> Add for NumVector<V>
impl<V: NumericVector> Add for NumVector<V>
Sourceimpl<V: NumericVector> AddAssign for NumVector<V>
impl<V: NumericVector> AddAssign for NumVector<V>
Sourcefn add_assign(&mut self, rhs: Self)
fn add_assign(&mut self, rhs: Self)
+= operation. Read moreSourceimpl<V: BitwiseVector> BitAnd for NumVector<V>
impl<V: BitwiseVector> BitAnd for NumVector<V>
Sourceimpl<V: BitwiseVector> BitAndAssign for NumVector<V>
impl<V: BitwiseVector> BitAndAssign for NumVector<V>
Sourcefn bitand_assign(&mut self, rhs: Self)
fn bitand_assign(&mut self, rhs: Self)
&= operation. Read moreSourceimpl<V: BitwiseVector> BitOr for NumVector<V>
impl<V: BitwiseVector> BitOr for NumVector<V>
Sourceimpl<V: BitwiseVector> BitOrAssign for NumVector<V>
impl<V: BitwiseVector> BitOrAssign for NumVector<V>
Sourcefn bitor_assign(&mut self, rhs: Self)
fn bitor_assign(&mut self, rhs: Self)
|= operation. Read moreSourceimpl<V: BitwiseVector> BitXor for NumVector<V>
impl<V: BitwiseVector> BitXor for NumVector<V>
Sourceimpl<V: BitwiseVector> BitXorAssign for NumVector<V>
impl<V: BitwiseVector> BitXorAssign for NumVector<V>
Sourcefn bitxor_assign(&mut self, rhs: Self)
fn bitxor_assign(&mut self, rhs: Self)
^= operation. Read moreSourceimpl<V: NumericVector> Bounded for NumVector<V>
impl<V: NumericVector> Bounded for NumVector<V>
Sourceimpl<V: GenericVector> Clone for NumVector<V>
impl<V: GenericVector> Clone for NumVector<V>
Sourceimpl<V: NumericVector> ConstOne for NumVector<V>
impl<V: NumericVector> ConstOne for NumVector<V>
Sourceimpl<V: NumericVector> ConstZero for NumVector<V>
impl<V: NumericVector> ConstZero for NumVector<V>
impl<V: GenericVector> Copy for NumVector<V>
Sourceimpl<V: GenericVector> Deref for NumVector<V>
impl<V: GenericVector> Deref for NumVector<V>
Sourceimpl<V: NumericVector> Div for NumVector<V>
impl<V: NumericVector> Div for NumVector<V>
Sourceimpl<V: NumericVector> DivAssign for NumVector<V>
impl<V: NumericVector> DivAssign for NumVector<V>
Sourcefn div_assign(&mut self, rhs: Self)
fn div_assign(&mut self, rhs: Self)
/= operation. Read moreSourceimpl<V> Float for NumVector<V>
Available on crate feature std only.
impl<V> Float for NumVector<V>
std only.Sourcefn classify(self) -> FpCategory
fn classify(self) -> FpCategory
Follows the logic of most important classification in the order: NaN (any) > Infinite (any) > Zero (all) > Subnormal (any) > Normal
Sourcefn is_sign_negative(self) -> bool
fn is_sign_negative(self) -> bool
Returns true if any lane is negative, false otherwise.
Sourcefn is_sign_positive(self) -> bool
fn is_sign_positive(self) -> bool
Returns true if all lanes are positive, false otherwise.
Sourcefn to_degrees(self) -> Self
fn to_degrees(self) -> Self
Sourcefn to_radians(self) -> Self
fn to_radians(self) -> Self
Sourcefn neg_infinity() -> Self
fn neg_infinity() -> Self
Sourcefn min_value() -> Self
fn min_value() -> Self
Sourcefn min_positive_value() -> Self
fn min_positive_value() -> Self
Sourcefn max_value() -> Self
fn max_value() -> Self
Sourcefn is_infinite(self) -> bool
fn is_infinite(self) -> bool
true if this value is positive infinity or negative infinity and
false otherwise. Read moreSourcefn ceil(self) -> Self
fn ceil(self) -> Self
Sourcefn round(self) -> Self
fn round(self) -> Self
0.0. Read moreSourcefn mul_add(self, a: Self, b: Self) -> Self
fn mul_add(self, a: Self, b: Self) -> Self
(self * a) + b with only one rounding
error, yielding a more accurate result than an unfused multiply-add. Read moreSourcefn log(self, base: Self) -> Self
fn log(self, base: Self) -> Self
Sourcefn hypot(self, other: Self) -> Self
fn hypot(self, other: Self) -> Self
x and y. Read moreSourcefn asin(self) -> Self
fn asin(self) -> Self
Sourcefn acos(self) -> Self
fn acos(self) -> Self
Sourcefn atan(self) -> Self
fn atan(self) -> Self
Sourcefn exp_m1(self) -> Self
fn exp_m1(self) -> Self
e^(self) - 1 in a way that is accurate even if the
number is close to zero. Read moreSourceimpl<V: FloatVector> FloatCore for NumVector<V>
impl<V: FloatVector> FloatCore for NumVector<V>
Sourcefn classify(self) -> FpCategory
fn classify(self) -> FpCategory
Follows the logic of most important classification in the order: NaN (any) > Infinite (any) > Zero (all) > Subnormal (any) > Normal
Sourcefn is_sign_negative(self) -> bool
fn is_sign_negative(self) -> bool
Returns true if any lane is negative, false otherwise.
Sourcefn is_sign_positive(self) -> bool
fn is_sign_positive(self) -> bool
Returns true if all lanes are positive, false otherwise.
Sourcefn recip(self) -> Self
fn recip(self) -> Self
Returns the reciprocal (1/x) of each lane. If you want to use an approximate
reciprocal, check the RealMath trait for that.
Sourcefn neg_infinity() -> Self
fn neg_infinity() -> Self
Sourcefn min_value() -> Self
fn min_value() -> Self
Sourcefn min_positive_value() -> Self
fn min_positive_value() -> Self
Sourcefn max_value() -> Self
fn max_value() -> Self
Sourcefn to_degrees(self) -> Self
fn to_degrees(self) -> Self
Sourcefn to_radians(self) -> Self
fn to_radians(self) -> Self
Sourcefn integer_decode(self) -> (u64, i16, i8)
fn integer_decode(self) -> (u64, i16, i8)
sign * mantissa * 2 ^ exponent. Read moreSourcefn is_infinite(self) -> bool
fn is_infinite(self) -> bool
true if the number is infinite. Read moreSourcefn is_normal(self) -> bool
fn is_normal(self) -> bool
true if the number is neither zero, infinite, subnormal or NaN. Read moreSourcefn ceil(self) -> Self
fn ceil(self) -> Self
Sourcefn round(self) -> Self
fn round(self) -> Self
0.0. Read moreSourcefn abs(self) -> Self
fn abs(self) -> Self
self. Returns FloatCore::nan() if the
number is FloatCore::nan(). Read moreSourceimpl<V> GenericSelectable for NumVector<V>where
V: GenericSelectable + GenericVector,
impl<V> GenericSelectable for NumVector<V>where
V: GenericSelectable + GenericVector,
Sourcetype SelectableMask = <V as GenericSelectable>::SelectableMask
type SelectableMask = <V as GenericSelectable>::SelectableMask
Self.Sourcefn select<M>(mask: M, t: Self, f: Self) -> Selfwhere
Self::SelectableMask: CastMask<M>,
fn select<M>(mask: M, t: Self, f: Self) -> Selfwhere
Self::SelectableMask: CastMask<M>,
t where mask is true, otherwise
from f.Sourceimpl<V: NumericVector> Mul for NumVector<V>
impl<V: NumericVector> Mul for NumVector<V>
Sourceimpl<V: FloatVector> MulAdd for NumVector<V>
impl<V: FloatVector> MulAdd for NumVector<V>
Sourceimpl<V: FloatVector> MulAddAssign for NumVector<V>
impl<V: FloatVector> MulAddAssign for NumVector<V>
Sourcefn mul_add_assign(&mut self, a: Self, b: Self)
fn mul_add_assign(&mut self, a: Self, b: Self)
*self = (*self * a) + bSourceimpl<V: NumericVector> MulAssign for NumVector<V>
impl<V: NumericVector> MulAssign for NumVector<V>
Sourcefn mul_assign(&mut self, rhs: Self)
fn mul_assign(&mut self, rhs: Self)
*= operation. Read moreSourceimpl<V: SignedVector> Neg for NumVector<V>
impl<V: SignedVector> Neg for NumVector<V>
Sourceimpl<V: NumericVector> Num for NumVector<V>
impl<V: NumericVector> Num for NumVector<V>
type FromStrRadixErr = <<V as GenericVector>::Element as Num>::FromStrRadixErr
Sourcefn from_str_radix(str: &str, radix: u32) -> Result<Self, Self::FromStrRadixErr>
fn from_str_radix(str: &str, radix: u32) -> Result<Self, Self::FromStrRadixErr>
2..=36). Read moreSourceimpl<V: NumericVector> NumCast for NumVector<V>
impl<V: NumericVector> NumCast for NumVector<V>
Sourceimpl<V: NumericVector> One for NumVector<V>
impl<V: NumericVector> One for NumVector<V>
Sourceimpl<V: PartialOrdVector> PartialEq for NumVector<V>
impl<V: PartialOrdVector> PartialEq for NumVector<V>
Sourceimpl<V: PartialOrdVector> PartialOrd for NumVector<V>
impl<V: PartialOrdVector> PartialOrd for NumVector<V>
Sourcefn partial_cmp(&self, other: &Self) -> Option<Ordering>
fn partial_cmp(&self, other: &Self) -> Option<Ordering>
Partial comparison between two vectors, returning None if
the vectors are not fully ordered. Only returns Some(Ordering) if
all lanes are less than, greater than, or equal.
Sourceimpl<V: NumericVector> Rem for NumVector<V>
impl<V: NumericVector> Rem for NumVector<V>
Sourceimpl<V: NumericVector> RemAssign for NumVector<V>
impl<V: NumericVector> RemAssign for NumVector<V>
Sourcefn rem_assign(&mut self, rhs: Self)
fn rem_assign(&mut self, rhs: Self)
%= operation. Read moreSourceimpl<V: BitshiftVector> Shl<NumVector<<V as GenericVector>::Unsigned>> for NumVector<V>
impl<V: BitshiftVector> Shl<NumVector<<V as GenericVector>::Unsigned>> for NumVector<V>
Sourceimpl<V: BitshiftVector> ShlAssign<NumVector<<V as GenericVector>::Unsigned>> for NumVector<V>
impl<V: BitshiftVector> ShlAssign<NumVector<<V as GenericVector>::Unsigned>> for NumVector<V>
Sourceimpl<V: BitshiftVector> ShlAssign<u32> for NumVector<V>
impl<V: BitshiftVector> ShlAssign<u32> for NumVector<V>
Sourcefn shl_assign(&mut self, rhs: u32)
fn shl_assign(&mut self, rhs: u32)
<<= operation. Read moreSourceimpl<V: BitshiftVector> Shr<NumVector<<V as GenericVector>::Unsigned>> for NumVector<V>
impl<V: BitshiftVector> Shr<NumVector<<V as GenericVector>::Unsigned>> for NumVector<V>
Sourceimpl<V: BitshiftVector> ShrAssign<NumVector<<V as GenericVector>::Unsigned>> for NumVector<V>
impl<V: BitshiftVector> ShrAssign<NumVector<<V as GenericVector>::Unsigned>> for NumVector<V>
Sourceimpl<V: BitshiftVector> ShrAssign<u32> for NumVector<V>
impl<V: BitshiftVector> ShrAssign<u32> for NumVector<V>
Sourcefn shr_assign(&mut self, rhs: u32)
fn shr_assign(&mut self, rhs: u32)
>>= operation. Read moreSourceimpl<V: NumericVector> Sub for NumVector<V>
impl<V: NumericVector> Sub for NumVector<V>
Sourceimpl<V: NumericVector> SubAssign for NumVector<V>
impl<V: NumericVector> SubAssign for NumVector<V>
Sourcefn sub_assign(&mut self, rhs: Self)
fn sub_assign(&mut self, rhs: Self)
-= operation. Read moreSourceimpl<V: GenericVector> ToPrimitive for NumVector<V>where
V::Element: ToPrimitive,
Implements conversion from NumVector<V> to primitive types by extracting
the first lane and converting that. Other lanes are ignored.
impl<V: GenericVector> ToPrimitive for NumVector<V>where
V::Element: ToPrimitive,
Implements conversion from NumVector<V> to primitive types by extracting
the first lane and converting that. Other lanes are ignored.
Sourcefn to_isize(&self) -> Option<isize>
fn to_isize(&self) -> Option<isize>
self to an isize. If the value cannot be
represented by an isize, then None is returned.Sourcefn to_i8(&self) -> Option<i8>
fn to_i8(&self) -> Option<i8>
self to an i8. If the value cannot be
represented by an i8, then None is returned.Sourcefn to_i16(&self) -> Option<i16>
fn to_i16(&self) -> Option<i16>
self to an i16. If the value cannot be
represented by an i16, then None is returned.Sourcefn to_i32(&self) -> Option<i32>
fn to_i32(&self) -> Option<i32>
self to an i32. If the value cannot be
represented by an i32, then None is returned.Sourcefn to_i128(&self) -> Option<i128>
fn to_i128(&self) -> Option<i128>
self to an i128. If the value cannot be
represented by an i128 (i64 under the default implementation), then
None is returned. Read moreSourcefn to_usize(&self) -> Option<usize>
fn to_usize(&self) -> Option<usize>
self to a usize. If the value cannot be
represented by a usize, then None is returned.Sourcefn to_u8(&self) -> Option<u8>
fn to_u8(&self) -> Option<u8>
self to a u8. If the value cannot be
represented by a u8, then None is returned.Sourcefn to_u16(&self) -> Option<u16>
fn to_u16(&self) -> Option<u16>
self to a u16. If the value cannot be
represented by a u16, then None is returned.Sourcefn to_u32(&self) -> Option<u32>
fn to_u32(&self) -> Option<u32>
self to a u32. If the value cannot be
represented by a u32, then None is returned.Sourcefn to_u128(&self) -> Option<u128>
fn to_u128(&self) -> Option<u128>
self to a u128. If the value cannot be
represented by a u128 (u64 under the default implementation), then
None is returned. Read moreSourcefn to_f32(&self) -> Option<f32>
fn to_f32(&self) -> Option<f32>
self to an f32. Overflows may map to positive
or negative inifinity, otherwise None is returned if the value cannot
be represented by an f32.Sourcefn to_f64(&self) -> Option<f64>
fn to_f64(&self) -> Option<f64>
self to an f64. Overflows may map to positive
or negative inifinity, otherwise None is returned if the value cannot
be represented by an f64. Read moreSourceimpl<V: NumericVector> Zero for NumVector<V>
impl<V: NumericVector> Zero for NumVector<V>